/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.marketplace.internal.bundle;

import java.io.File;

import java.util.List;
import java.util.jar.Manifest;

import org.osgi.framework.Bundle;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Ryan Park
 */
@Component
public class BundleManagerUtil {

	public static Bundle getBundle(String symbolicName, String version) {
		return _bundleManagerImpl.getBundle(symbolicName, version);
	}

	public static List<Bundle> getBundles() {
		return _bundleManagerImpl.getBundles();
	}

	public static List<Bundle> getInstalledBundles() {
		return _bundleManagerImpl.getInstalledBundles();
	}

	public static Manifest getManifest(File file) {
		return _bundleManagerImpl.getManifest(file);
	}

	public static List<Bundle> installLPKG(File file) throws Exception {
		return _bundleManagerImpl.installLPKG(file);
	}

	public static boolean isInstalled(Bundle bundle) {
		return _bundleManagerImpl.isInstalled(bundle);
	}

	public static boolean isInstalled(String symbolicName, String version) {
		return _bundleManagerImpl.isInstalled(symbolicName, version);
	}

	public static void uninstallBundle(Bundle bundle) {
		_bundleManagerImpl.uninstallBundle(bundle);
	}

	public static void uninstallBundle(String symbolicName, String version) {
		_bundleManagerImpl.uninstallBundle(symbolicName, version);
	}

	@Reference(unbind = "-")
	protected void setBundleManager(BundleManagerImpl bundleManagerImpl) {
		_bundleManagerImpl = bundleManagerImpl;
	}

	private static BundleManagerImpl _bundleManagerImpl;

}